pub struct TerrainChunkArrayBg {
pub heightmap_array: Option<Handle<Texture>>,
pub splatmap_array: Option<Handle<Texture>>,
}Fields
heightmap_array: Option<Handle<Texture>>splatmap_array: Option<Handle<Texture>>Trait Implementations
Sourceimpl Clone for TerrainChunkArrayBg
impl Clone for TerrainChunkArrayBg
Sourcefn clone(&self) -> TerrainChunkArrayBg
fn clone(&self) -> TerrainChunkArrayBg
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for TerrainChunkArrayBg
impl Default for TerrainChunkArrayBg
Sourcefn default() -> TerrainChunkArrayBg
fn default() -> TerrainChunkArrayBg
Returns the “default value” for a type. Read more
Sourceimpl RenderBinding for TerrainChunkArrayBg
impl RenderBinding for TerrainChunkArrayBg
type Params = ()
Sourcefn describe(
&mut self,
_params: &SystemParamItem<'_, '_, Self::Params>,
builder: &mut RenderBindingBuilder,
)
fn describe( &mut self, _params: &SystemParamItem<'_, '_, Self::Params>, builder: &mut RenderBindingBuilder, )
Describes the render binding. This is used to specify the
RenderData that should be used to create the bind group layout and bind group entries, and to specify the binding index for each buffer and texture.Sourcefn label(&self) -> &str
fn label(&self) -> &str
Whether the gpu asset should be recreated. This is called every frame. The default is to never recreate (None).
Sourcefn has_dependencies(&self) -> bool
fn has_dependencies(&self) -> bool
Whether this render binding has any dependencies on render data. By default, false.
Sourceimpl TypePath for TerrainChunkArrayBg
impl TypePath for TerrainChunkArrayBg
Sourcefn type_path() -> &'static str
fn type_path() -> &'static str
Returns the fully qualified path of the underlying type. Read more
Sourcefn short_type_path() -> &'static str
fn short_type_path() -> &'static str
Returns a short, pretty-print enabled path to the type. Read more
Sourcefn type_ident() -> Option<&'static str>
fn type_ident() -> Option<&'static str>
Sourcefn crate_name() -> Option<&'static str>
fn crate_name() -> Option<&'static str>
Sourceimpl VisitAssetDependencies for TerrainChunkArrayBg
impl VisitAssetDependencies for TerrainChunkArrayBg
fn visit_dependencies(&self, visit: &mut impl FnMut(UntypedAssetId))
impl Asset for TerrainChunkArrayBg