pub struct TerrainRendererGPU {
pub ready: bool,
pub pos_to_tile: HashMap<ChunkPos, usize>,
pub tiles: Vec<TerrainRenderTileGPU>,
pub dirty: Vec<Option<(ChunkPos, u32, u32, Vec<u8>)>>,
}Expand description
Holds the tiles used for rendering. Note that all tiles are not necessarily rendered.
Fields
ready: boolTrue if the renderer has been initialized (i.e., the bind group of each tiles have been created and is ready for rendering)
pos_to_tile: HashMap<ChunkPos, usize>Mapping of the tile position (x, z) to its tile index in the tiles vector
tiles: Vec<TerrainRenderTileGPU>A list of terrain render tiles that make up the entire terrain.
dirty: Vec<Option<(ChunkPos, u32, u32, Vec<u8>)>>Implementations
Sourceimpl TerrainRendererGPU
impl TerrainRendererGPU
pub fn extract_dirty( main_terrain_extractor: &TerrainExtractor, render_terrain_extractor: &mut TerrainExtractor, terrain_renderer_query: Query<'_, '_, &TerrainRenderer>, gpu_terrain_renderer: &mut TerrainRendererGPU, )
pub fn upload_dirty( gpu_terrain_renderer: ResMut<'_, TerrainRendererGPU>, textures: Res<'_, RenderAssets<GpuTexture>>, render_instance: Res<'_, RenderInstance>, )
pub fn prepare_bind_groups( asset_server: Res<'_, AssetServer>, gpu_terrain_renderer: ResMut<'_, TerrainRendererGPU>, )